@@ -14,7 +14,7 @@ def get_message(post):
     return post['message']
 
 
-def get_created_at(post):
+def get_creation_date(post):
     return post['created_at']
 
 
