@@ -1,14 +1,10 @@
 from geopy import distance
-from firstimpression.api import request_json
 import xml.etree.ElementTree as ET
 
 METER_TO_KILOMETER_DIVIDER = 1000
 KILOMETER_APPENDIX = ' km'
 UNKNOWN_JAM_DISTANCE_MESSAGE = 'onbekend'
 
-def get_traffic_info(url, header, params):
-    return request_json(url, header, params)
-
 
 def get_road_type(circumstance):
     try:
@@ -163,7 +159,7 @@ def sort_longest_jams(jams):
 
 def sort_closest_jams(jams):
     # Sorts jams that are closest to own location
-    return sorted(jams, key=lambda i: i['distance_to_circumstances'])
+    return sorted(jams, key=lambda i: i['distance_to_circumstance'])
 
 
 def get_jams(circumstances, jam_type):
@@ -193,7 +189,7 @@ def get_total_jams_delay(jams):
 
 
 def get_total_length_string(total_length):
-    return '{} km'.format(total_length)
+    return '{}{}'.format(total_length, KILOMETER_APPENDIX)
 
 
 def get_only_highways(circumstances):
