@@ -1,4 +1,5 @@
 from tempfile import gettempdir
+import os
 import mimetypes
 
 mimetypes.init()
@@ -10,21 +11,23 @@ PICTURE_FORMATS = {
 
 TEMP_FOLDER = gettempdir()
 LOCAL_INTEGRATED_FOLDER = 'C:/Users/Public/Documents/Scala/LocalIntegratedContent'
+PLACEHOLDER_FOLDER = os.path.join(LOCAL_INTEGRATED_FOLDER, 'placeholders')
 
-APIS = [
-    '',
-    'BBC',
-    'NS',
-    'NU',
-    'TRAFFIC',
-    'INSTAGRAM',
-    'WEATHER',
-    'AMBER_ALERT',
-    'AMS_AIRPORT',
-    'CHUCK_NORRIS',
-    'EHV_AIRPORT',
-    'FACEBOOK'
-    ]
+APIS = {
+    'amber':'AMBER_ALERT',
+    'schiphol':'AMS_AIRPORT',
+    'bbc':'BBC',
+    'ns':'NS',
+    'traffic':'TRAFFIC',
+    'insta':'INSTAGRAM',
+    'weather':'WEATHER',
+    'jokes':'CHUCK_NORRIS',
+    'eindhoven':'EHV_AIRPORT',
+    'facebook':'FACEBOOK',
+    'trends':'GOOGLE_TRENDS',
+    'news_polish':'INTERIA',
+    'concerts':'SONGKICK'
+}
 
 VIDEO_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'video']
 IMG_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'image']
